package com.ruoyi.web.controller.rl;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.RlUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.IRlUserService;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 用户信息
 *
 * @author ruoyi 代理商
 */
@RestController
@RequestMapping("/user/user")
public class RlUserController extends BaseController
{
    @Resource
    private IRlUserService eUserService;

    /**
     * 获取用户列表
     */
    @GetMapping("/list")
    public TableDataInfo list(RlUser rlUser)
    {
        startPage();
        List<RlUser> list = eUserService.selectUserList(rlUser);
        return getDataTable(list);
    }

//    /**
//     * 根据手机号快速搜索用户列表
//     */
//    @GetMapping("/fast/search")
//    public AjaxResult fastSearch(String phonenumber)
//    {
//        List<LabelVo> list = eUserService.fastSearch(phonenumber);
//        return success(list);
//    }


//    @Log(title = "用户管理", businessType = BusinessType.IMPORT)
//    @PostMapping("/importData")
//    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception
//    {
//        ExcelUtil<EUser> util = new ExcelUtil<EUser>(EUser.class);
//        List<EUser> userList = util.importExcel(file.getInputStream());
//        String operName = getUsername();
//        String message = eUserService.importUser(userList, updateSupport, operName);
//        return success(message);
//    }

    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<RlUser> util = new ExcelUtil<>(RlUser.class);
        util.importTemplateExcel(response, "用户数据");
    }

    /**
     * 根据用户编号获取详细信息
     */
    @GetMapping(value = { "/", "/{userId}" })
    public AjaxResult getInfo(@PathVariable(value = "userId", required = false) Long userId)
    {
        AjaxResult ajax = AjaxResult.success();
        if (StringUtils.isNotNull(userId))
        {
            RlUser rlUser = eUserService.selectUserById(userId);
            ajax.put(AjaxResult.DATA_TAG, rlUser);
        }
        return ajax;
    }

//    /**
//     * 新增用户
//     */
//    @Log(title = "用户管理", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@Validated @RequestBody EUser user)
//    {
//        if (!eUserService.checkUserNameUnique(user))
//        {
//            return error("新增用户'" + user.getUserName() + "'失败，登录账号已存在");
//        }
//        else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !eUserService.checkPhoneUnique(user))
//        {
//            return error("新增用户'" + user.getUserName() + "'失败，手机号码已存在");
//        }
//        else if (StringUtils.isNotEmpty(user.getEmail()) && !eUserService.checkEmailUnique(user))
//        {
//            return error("新增用户'" + user.getUserName() + "'失败，邮箱账号已存在");
//        }
//        user.setCreateBy(getUsername());
//        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
//        return toAjax(eUserService.insertUser(user));
//    }
//
//    /**
//     * 修改用户
//     */
//    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@Validated @RequestBody EUser user)
//    {
//        if (!eUserService.checkUserNameUnique(user))
//        {
//            return error("修改用户'" + user.getUserName() + "'失败，登录账号已存在");
//        }
//        else if (StringUtils.isNotEmpty(user.getPhonenumber()) && !eUserService.checkPhoneUnique(user))
//        {
//            return error("修改用户'" + user.getUserName() + "'失败，手机号码已存在");
//        }
//        else if (StringUtils.isNotEmpty(user.getEmail()) && !eUserService.checkEmailUnique(user))
//        {
//            return error("修改用户'" + user.getUserName() + "'失败，邮箱账号已存在");
//        }
//        user.setUpdateBy(getUsername());
//        return toAjax(eUserService.updateUser(user));
//    }


//    /**
//     * 绑定系统用户
//     */
//    @Log(title = "绑定系统用户", businessType = BusinessType.UPDATE)
//    @PutMapping("/bandSystemUser")
//    public AjaxResult bandSystemUser(@RequestBody EUser user)
//    {
//        return toAjax(eUserService.bandSystemUser(user));
//    }

//    /**
//     * 删除用户
//     */
//    @Log(title = "用户管理", businessType = BusinessType.DELETE)
//    @DeleteMapping("/{userIds}")
//    public AjaxResult remove(@PathVariable Long[] userIds)
//    {
//        if (ArrayUtils.contains(userIds, getUserId()))
//        {
//            return error("当前用户不能删除");
//        }
//        return toAjax(eUserService.deleteUserByIds(userIds));
//    }

//    /**
//     * 重置密码
//     */
//    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
//    @PutMapping("/resetPwd")
//    public AjaxResult resetPwd(@RequestBody EUser user)
//    {
//        user.setPassword(SecurityUtils.encryptPassword(user.getPassword()));
//        user.setUpdateBy(getUsername());
//        return toAjax(eUserService.resetPwd(user));
//    }

    /**
     * 状态修改
     */
    @Log(title = "用户管理", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody RlUser user)
    {
        user.setUpdateBy(getUsername());
        return toAjax(eUserService.updateUserStatus(user));
    }


}
