package com.ruoyi.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.RlDevice;

import java.util.List;

/**
 * 设备Mapper接口
 *
 * @author 邱贞招
 * @date 2024-04-05
 */
public interface RlDeviceMapper extends BaseMapper<RlDevice>
{
    /**
     * 查询设备
     *
     * @param deviceId 设备主键
     * @return 设备
     */
    public RlDevice selectEDeviceByDeviceId(Long deviceId);

    /**
     * 根据mac号查询设备信息
     *
     * @param mac 设备列表主键
     * @return 设备列表
     */
    public RlDevice selectEDeviceByMac(String mac);

    /**
     * 根据SN查询设备信息
     *
     * @param sn 设备SN
     * @return 设备列表
     */
    public RlDevice selectEDeviceBySn(String sn);


    /**
     * 查询设备列表
     *
     * @param RlDevice 设备
     * @return 设备集合
     */
    public List<RlDevice> selectEDeviceList(RlDevice RlDevice);

    /**
     * 查询设备列表（带数据隔离）
     *
     * @param RlDevice 设备
     * @return 设备集合
     */
    public List<RlDevice> selectEDeviceListWithIsolate(RlDevice RlDevice);

    /**
     * 新增设备
     *
     * @param RlDevice 设备
     * @return 结果
     */
    public int insertEDevice(RlDevice RlDevice);

    /**
     * 修改设备
     *
     * @param RlDevice 设备
     * @return 结果
     */
    public int updateEDevice(RlDevice RlDevice);

    /**
     * 修改设备
     *
     * @param RlDevice 设备
     * @return 结果
     */
    public int updateEDevice2(RlDevice RlDevice);

    /**
     * 根据SN修改设备
     *
     * @param RlDevice 设备
     * @return 结果
     */
    public int updateEDeviceBySn(RlDevice RlDevice);

    /**
     * 删除设备
     *
     * @param deviceId 设备主键
     * @return 结果
     */
    public int deleteEDeviceByDeviceId(Long deviceId);

    /**
     * 批量删除设备
     *
     * @param deviceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEDeviceByDeviceIds(Long[] deviceIds);

//    /**
//     * 一键上线
//     *
//     * @param deviceIds 需要一键上线的设备主键集合
//     * @return 结果
//     */
//    public int oneClickOnline(Long[] deviceIds);
//
//    /**
//     * 一键下线
//     *
//     * @param deviceIds 需要一键下线的设备主键集合
//     * @return 结果
//     */
//    public int oneClickOffline(Long[] deviceIds);
//
//    /**
//     * 一键入仓
//     *
//     * @param deviceIds 需要一键入仓的设备主键集合
//     * @return 结果
//     */
//    public int oneClickWarehousing(Long[] deviceIds);
//
//
//    /**
//     * 有订单车辆
//     */
//    String getInOrderDevice(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);
//
//    /**
//     * 无订单车辆
//     */
//    String getNoOrderDevice(@Param("timeStart") String timeStart, @Param("timeEnd") String timeEnd, @Param("areaId") String areaId);
//
//    public int batchDisable(String[] sns);
//

    RlDevice checkSNUnique(String sn);

    RlDevice checkMACUnique(String mac);
}
